﻿/// <reference path="typings/c1.mvc.basic.lib.d.ts" />
class DC101Controller {

    /** 共通処理クラス */
    public common: CommonController;

    /** グリッド*/
    public grid: wijmo.grid.FlexGrid;
    /** グリッドID */
    private readonly gridId = "#results";
    /** デフォルトレイアウトのKey */
    private readonly defaultLayoutKey = "DC101.DefaultLayout";
    /** ユーザレイアウトのKey */
    private readonly userLayoutKey = "DC101.UserLayout";
    /** Excel出力のファイル名の接頭辞 */
    private readonly filenamePrefix = "DC101_List_";
    /** 送信ボタンのID*/
    private readonly submitButtonId = "#submitSearch";
    /** 日付種類選択のID*/
    private readonly selectorInputId = "#TgtPeriodCmb";
    /** 日付FromのID*/
    private readonly fromDateInputId = "#fromDate";
    /** 日付ToのID*/
    private readonly toDateInputId = "#toDate";

    constructor(common: CommonController) {
        this.common = common;

    }

    /**
     * 全て読み完了後に実行する(c1.documentReadyにて実行)
     */
    public documentReady = (): void => {
        this.grid = wijmo.Control.getControl(this.gridId) as wijmo.grid.FlexGrid;
        this.common.initializeGridHeaderTooltip(this.gridId);
        this.common.initializeGridSelectedNone(this.gridId);
        this.common.initializeGridLayoutLoading(this.gridId, this.defaultLayoutKey, this.userLayoutKey);
        this.common.initializeSidePanelToggle();
        this.common.initializeAdjustGridHeight(this.gridId, "#search-filter");
        this.common.initializeSubmitLoading(this.submitButtonId);
        this.initializeInputSetting();
    }

    /** 入力コントロールの初期化 */
    private initializeInputSetting() {
        //対象期間
        const selector = wijmo.Control.getControl(this.selectorInputId) as wijmo.input.ComboBox;
        selector.selectedIndexChanged.addHandler((e: wijmo.input.ComboBox) => {
            const fromDate = wijmo.Control.getControl(this.fromDateInputId) as wijmo.input.InputDate;
            const toDate = wijmo.Control.getControl(this.toDateInputId) as wijmo.input.InputDate;
            const isDisabled = (e.selectedValue === 0 || e.selectedValue === 1);
            fromDate.isDisabled = isDisabled;
            toDate.isDisabled = isDisabled;
            if (isDisabled) {
                fromDate.text = '';
                toDate.text = '';
            }            

            //「仕掛中含む」、「保留/中止含む」のチェックボックス
            //「完成実績」選択時のみ、選択が可能
            if (selector.selectedValue === 3) {
                $("#Filters_SIKAKARI").prop('disabled', false);                
                $("#Filters_HORYU_TYUSI").prop('disabled', false);
                $("#lblSikakari").removeClass("color-gray");
                $("#lblHoryuTyusi").removeClass("color-gray");
            } else {
                $("#Filters_SIKAKARI").prop('checked', '');
                $("#Filters_HORYU_TYUSI").prop('checked', '');
                $("#Filters_SIKAKARI").prop('disabled', true);                
                $("#Filters_HORYU_TYUSI").prop('disabled', true);
                $("#lblSikakari").addClass("color-gray");
                $("#lblHoryuTyusi").addClass("color-gray");
            }
        });
        selector.onSelectedIndexChanged();
        this.common.initializeFromToInputDate(this.fromDateInputId, this.toDateInputId);           
    }

    /**
     * グリッドのItemFormatter
     * @param {wijmo.grid.GridPanel} panel パネル
     * @param {number} r 行INDEX
     * @param {number} c 列INDEX
     * @param {HTMLDivElement} cell Cell
     */
    public itemFormatter = (panel: wijmo.grid.GridPanel, r: number, c: number, cell: HTMLDivElement): void => {
        //１行用のitemFormatterを適用する
        this.common.itemFormatter(panel, r, c, cell);

        //「工事番号」でDCD01へ遷移
        // 非表示行にリンクを設定
        if (panel.columns[c].binding === "KOJI_NO" &&
            panel.cellType === wijmo.grid.CellType.Cell) {
            const url = panel.grid.getCellData(r, panel.grid.getColumn("LinkKojiNo").index, false) as string;
            cell.innerHTML = `<a href="${url}" onclick="common.linkLoadingStart(event)">${cell.textContent}</a>`;
        }

        // 「比率」の背景色＆フォント色制御
        if (panel.cellType === wijmo.grid.CellType.Cell && panel.columns[c].binding === "HIRITSU") {
            const ratio = panel.grid.getCellData(r, panel.grid.getColumn("HIRITSU").index, false) as string;
            var intRatio = parseFloat(ratio) as number;
            if (intRatio > 100.00) {
                cell.classList.add("grid-cell-danger");
                cell.classList.add("bg-primary");
            }
        }
    }

    /**
     * 検索結果のエクスポート
     */
    public exportExcel(): void {
        const filename = this.filenamePrefix + this.common.getNowDateTimeText() + ".xlsx";
        this.common.exportExcel(filename, this.gridId);
    };

    /** グリッドレイアウトのクリア */
    public clearColumnLayout(): void {
        const layout = this.common.loadColumnLayout(this.defaultLayoutKey);
        if (layout != null) {
            this.grid.columnLayout = layout;
        }        
    }
    /** グリッドレイアウトの保存 */
    public saveColumnLayout(): void {
        this.common.saveColumnLayout(this.userLayoutKey, this.grid.columnLayout);
    }
    /** グリッドレイアウトの復元 */
    public loadColumnLayout(): void {
        const layout = this.common.loadColumnLayout(this.userLayoutKey);
        if (layout != null) {
            this.grid.columnLayout = layout;
        }
    }
}

//commonの初期読み込み
const dc101 = new DC101Controller(common);

//conponentoneのコンポーネントが読み込まれた後
c1.documentReady(dc101.documentReady);

