/// <reference path="_references.js" />
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var CommonController = /** @class */ (function () {
    /**
     * コンストラクタ 読み込み時に実行
     */
    function CommonController() {
        var _this = this;
        /** Validationの後処理*/
        this.postProcessValidation = function () { };
        /** body-contentを取得するセレクタ*/
        this.bodyContentSelector = ".body-content";
        /**
         * 定期実行
         * セッション切れを解消する為に定期的に通信を実行
         */
        this.intervalRequest = function () {
            setInterval(function () {
                var url = "CostHome/Interval";
                $.ajax({
                    type: "GET",
                    url: url,
                    success: function (result) {
                        var ret = result;
                        console.debug(ret);
                    },
                    error: function () {
                    }
                });
            }, 60000);
        };
        /**
         * validatorの初期化
         * HTMLの描画前に実行する必要があるため、COMMONのconstructorで実行
         */
        this.initializeValidator = function () {
            if ($.validator != null) {
                $.validator.unobtrusive.options = {};
                $.validator.unobtrusive.options = {
                    //テキストを挿入する場合はliタグで
                    errorElement: "li",
                    //チェック時に実行する処理
                    errorPlacement: function (error, inputElement) {
                        //エラーメッセージの取得、複数ある場合<br/>タグで改行して連結
                        var errorMessage = _(error)
                            .filter(function (x) { return x.innerText != null; })
                            .map(function (x) { return x.innerText; })
                            .reduce(function (x, y) { return x + "<br />" + y; });
                        if (errorMessage != null && errorMessage != "") {
                            //ツールチップ
                            _.each(inputElement, function (x) {
                                //通常のinput属性
                                var element = $(x);
                                if (x.parentElement != null && x.parentElement.classList.contains("wj-input-group")) {
                                    //C1のcombobox
                                    //element = $(x.parentElement).find(`[ wj-name = "${x.name}" ]`) as JQuery<HTMLInputElement>;
                                    element = $(x.parentElement);
                                    element.parents(".wj-control").addClass("input-validation-error");
                                }
                                element.tooltip({ html: true, placement: "auto", trigger: "click hover focus", title: errorMessage, container: "body" }); // HTMLタグ有効化でツールチップを表示
                                element.tooltip("show");
                            });
                        }
                        else {
                            _.each(inputElement, function (x) {
                                //通常のinput属性
                                var element = $(x);
                                if (x.parentElement != null && x.parentElement.classList.contains("wj-input-group")) {
                                    //C1のcombobox
                                    element = $(x.parentElement);
                                    element.parents(".wj-control").removeClass("input-validation-error");
                                }
                                $(x).tooltip("destroy"); // Clear the title - there is no error associated anymore
                            });
                        }
                        //ヘッダにエラーメッセージを表示している場合を考慮し、レイアウト調整
                        $('#field-validation-area').collapse('show');
                        _this.resizeBodyPaddingTop();
                        _this.postProcessValidation();
                    },
                    success: function () {
                        //ヘッダにエラーメッセージを表示している場合を考慮し、レイアウト調整
                        _this.resizeBodyPaddingTop();
                        _this.postProcessValidation();
                    }
                };
            }
        };
        /**
         * グリッドのItemFormatter
         * @param {wijmo.grid.GridPanel} panel パネル
         * @param {number} r 行INDEX
         * @param {number} _c 列INDEX
         * @param {HTMLDivElement} cell Cell
         */
        this.itemFormatter = function (panel, r, _c, cell) {
            //ヘッダー高さ調節・改行有効
            if (panel.cellType === wijmo.grid.CellType.ColumnHeader) {
                //cell.classList.add("grid-header-base");
                //ヘッダは左寄せ
                cell.style.textAlign = "left";
                //panel.rows[r].height = FlexgridLayout.HeaderHeight;
            }
            else if (panel.cellType === wijmo.grid.CellType.Cell) {
                panel.rows[r].height = FlexgridLayout.RowHeight;
            }
        };
        /**
         * グリッドのItemFormatterDouble(２行用)
         * @param {wijmo.grid.GridPanel} panel パネル
         * @param {number} r 行INDEX
         * @param {number} _c 列INDEX
         * @param {HTMLDivElement} cell Cell
         */
        this.itemFormatterDouble = function (panel, r, _c, cell) {
            //ヘッダー高さ調節・改行有効
            if (panel.cellType === wijmo.grid.CellType.ColumnHeader) {
                cell.classList.add("grid-header-base");
                //ヘッダは左寄せ
                cell.style.textAlign = "left";
                panel.rows[r].height = FlexgridLayout.HeaderHeightDouble;
            }
            else if (panel.cellType === wijmo.grid.CellType.Cell) {
                panel.rows[r].height = FlexgridLayout.RowHeight;
            }
        };
        /**
         * グリッドの計画日と実績日の背景色＆フォント色制御
         * @param {wijmo.grid.GridPanel} panel パネル
         * @param {number} r 行INDEX
         * @param {number} _c 列INDEX
         * @param {HTMLDivElement} cell Cell
         */
        this.changeCellBackFont = function (panel, r, _c, cell, yotei, jisseki) {
            if (panel.columns[_c].binding === jisseki &&
                panel.cellType === wijmo.grid.CellType.Cell) {
                var sysDate = new Date();
                var yoteiString = panel.grid.getCellData(r, panel.grid.getColumn(yotei).index, false);
                var yoteiDate = panel.grid.getCellData(r, panel.grid.getColumn(yotei).index, false);
                var jissekiString = panel.grid.getCellData(r, panel.grid.getColumn(jisseki).index, false);
                var jissekiDate = panel.grid.getCellData(r, panel.grid.getColumn(jisseki).index, false);
                if (yoteiString === "" || yoteiString === null) {
                    //予定日がない場合は、制御なし
                }
                else {
                    //予定日がある場合
                    if (jissekiString === "" || jissekiString === null) {
                        //実績日がなくて、予定日から遅れていれば、背景色を赤へ
                        if (yoteiDate < sysDate) {
                            cell.classList.add("grid-cell-danger");
                        }
                    }
                    else {
                        //実績日があって、予定日から遅れていれば、フォント色を赤へ
                        if (yoteiDate < jissekiDate) {
                            cell.classList.add("text-danger");
                        }
                    }
                }
            }
        };
        /**
         * グリッドの計画日と実績日の背景色＆フォント色制御（グレーアウト）
         * @param {wijmo.grid.GridPanel} panel パネル
         * @param {number} r 行INDEX
         * @param {number} _c 列INDEX
         * @param {HTMLDivElement} cell Cell
         */
        this.changeCellBackFontGrayOut = function (panel, r, _c, cell, yotei, jisseki) {
            //計画日
            if (panel.columns[_c].binding === yotei &&
                panel.cellType === wijmo.grid.CellType.Cell) {
                var yoteiString = panel.grid.getCellData(r, panel.grid.getColumn(yotei).index, false);
                var jissekiString = panel.grid.getCellData(r, panel.grid.getColumn(jisseki).index, false);
                //予定日がない
                if (yoteiString === "" || yoteiString === null) {
                    //実績日がない
                    if (jissekiString === "" || jissekiString === null) {
                        cell.classList.add("grid-cell-none");
                    }
                }
            }
            //実績日
            if (panel.columns[_c].binding === jisseki &&
                panel.cellType === wijmo.grid.CellType.Cell) {
                var yoteiString = panel.grid.getCellData(r, panel.grid.getColumn(yotei).index, false);
                var jissekiString = panel.grid.getCellData(r, panel.grid.getColumn(jisseki).index, false);
                //予定日がない
                if (yoteiString === "" || yoteiString === null) {
                    //実績日がない
                    if (jissekiString === "" || jissekiString === null) {
                        cell.classList.add("grid-cell-none");
                    }
                }
            }
        };
        /**
         * Export Excel のオプション
         */
        this.flexGridXlsxOptions = {
            includeCellStyles: true,
            includeColumnHeaders: true,
            includeColumns: function (column) { return column.isVisible; },
            formatItem: function (args) {
                if ((args.xlsxCell.style != null) && (args.panel.columns[args.col].dataType == wijmo.DataType.String)) {
                    args.xlsxCell.style.format = "@";
                }
            }
        };
        /** Loadingの開始の遅延時間(ms)*/
        this.loadingStartTransitionDuration = 3000;
        /** Loadingの終了の遅延時間(ms)*/
        this.loadingEndTransitionDuration = 500;
        /**
         * viewに隠しで持っている値を取得する
         */
        this.getHiddenValue = function (name) { return $(':hidden[name="' + name + '"]').val(); };
        this.initializeValidator();
    }
    /**
     * HTML読み込み後に実行する処理
     */
    CommonController.prototype.ready = function () {
        this.resizeBodyPaddingTop();
        this.initializeHistoryBack();
        this.intervalRequest();
    };
    /**
     * 現在の日時を返す
     */
    CommonController.prototype.getNowDateTimeText = function () {
        var nowTime = new Date();
        var time = nowTime.getFullYear() + "";
        time += ("0" + (nowTime.getMonth() + 1)).slice(-2);
        time += ("0" + nowTime.getDate()).slice(-2);
        time += ("0" + nowTime.getHours()).slice(-2);
        time += ("0" + nowTime.getMinutes()).slice(-2);
        time += ("0" + nowTime.getSeconds()).slice(-2);
        return time;
    };
    /**
     * グリッドヘッダにツールチップを表示
     * @param gridId グリッドのID
     */
    CommonController.prototype.initializeGridHeaderTooltip = function (gridId) {
        var grid = wijmo.Control.getControl(gridId);
        /*ヘッダにツールチップを表示*/
        var tooltip = new wijmo.Tooltip();
        grid.hostElement.addEventListener("mouseover", function (e) {
            var ht = grid.hitTest(e);
            var rng = null;
            if (ht.range != rng) {
                if (ht.cellType === wijmo.grid.CellType.ColumnHeader) {
                    rng = ht.range;
                    var data = grid.columnHeaders.getCellData(rng.row, rng.col, true);
                    var tipContent_1 = data;
                    var cellElement = document.elementFromPoint(e.clientX, e.clientY);
                    var cellBounds_1 = wijmo.Rect.fromBoundingRect(cellElement.getBoundingClientRect());
                    setTimeout(function () {
                        tooltip.show(grid.hostElement, tipContent_1, cellBounds_1);
                    }, FlexgridLayout.gridHeaderTooltipDelay);
                }
            }
        });
        grid.hostElement.addEventListener("mouseout", function (_e) {
            tooltip.hide();
            tooltip.dispose();
        });
    };
    /**
     * グリッドの初期表示時点で1行目選択済みなので、選択されないようにする
     * @param gridId グリッドのID
     */
    CommonController.prototype.initializeGridSelectedNone = function (gridId) {
        var grid = wijmo.Control.getControl(gridId);
        //初期表示時点で1行目選択済みなので、選択されないようにする
        grid.select(-1, -1);
    };
    /**
     * レイアウト保存状態のロード
     * @param gridId グリッドのID
     */
    CommonController.prototype.initializeGridLayoutLoading = function (gridId, defaultLayoutKey, userLayoutKey) {
        var grid = wijmo.Control.getControl(gridId);
        //レイアウト初期状態の保存
        this.saveColumnLayout(defaultLayoutKey, grid.columnLayout);
        //レイアウト保存状態のロード
        var userLayout = this.loadColumnLayout(userLayoutKey);
        if (userLayout != null) {
            grid.columnLayout = userLayout;
            //工程を含む列が無ければ、そのまま復元
            //if (!containsKoteiColumns) {
            //    grid.columnLayout = userLayout;
            //} else {
            //    grid.columnLayout = this.getContainsKoteiColumnsLayout(grid.columnLayout, userLayout);
            //}
        }
    };
    /**
     * 工程列が存在するレイアウトの場合のColumnsLayoutを取得する
     * @param defaultLayout
     * @param userLayout
     */
    CommonController.prototype.getContainsKoteiColumnsLayout = function (defaultLayout, userLayout) {
        var _a;
        //工程列の最大を取得
        var findKoteiRegex = /KOTEI_(CODE_|NAME_|CHECK_|)../;
        var getLayoutKoteiMax = function (columns) {
            var koteiMax = _(columns)
                .filter(function (x) { return findKoteiRegex.test(x.binding); })
                .map(function (x) { return Number(x.binding.slice(-2)); })
                .max();
            if (koteiMax === undefined) {
                return 0;
            }
            else {
                return koteiMax;
            }
        };
        var defaultLayoutObj = JSON.parse(defaultLayout);
        var userLayoutObj = JSON.parse(userLayout);
        var defaultLayoutKoteiMax = getLayoutKoteiMax(defaultLayoutObj.columns);
        var userLayoutKoteiMax = getLayoutKoteiMax(userLayoutObj.columns);
        if (defaultLayoutKoteiMax === userLayoutKoteiMax) {
            //表示列が同じ場合、そのまま復元
            return userLayout;
        }
        else if (defaultLayoutKoteiMax > userLayoutKoteiMax) {
            //表示列が多い場合、最大の工程の後ろに、差分を追加して復元
            var diffLayoutColumns = _.filter(defaultLayoutObj.columns, function (x) { return findKoteiRegex.test(x.binding) && Number(x.binding.slice(-2)) > userLayoutKoteiMax; });
            var insertTagetIndex = _.findLastIndex(userLayoutObj.columns, function (x) { return findKoteiRegex.test(x.binding) && Number(x.binding.slice(-2)) === userLayoutKoteiMax; }) + 1;
            (_a = userLayoutObj.columns).splice.apply(_a, __spreadArrays([insertTagetIndex, 0], diffLayoutColumns));
            return JSON.stringify(userLayoutObj);
        }
        else {
            //表示列が少ない場合、差分を削除して復元
            _.remove(userLayoutObj.columns, function (x) { return findKoteiRegex.test(x.binding) && Number(x.binding.slice(-2)) > defaultLayoutKoteiMax; });
            return JSON.stringify(userLayoutObj);
        }
    };
    /**
     * ヘッダに合わせ、Bodyを下げる
     */
    CommonController.prototype.resizeBodyPaddingTop = function () {
        // navbarの高さを取得する
        var height = $('.navbar').innerHeight();
        if (height != null) {
            // bodyのpaddingにnavbarの高さを設定する
            $(this.bodyContentSelector).css('padding-top', height);
        }
    };
    /**
     * チェックボックスとフィルタ処理を対応させる初期設定
     * @param gridId グリッドのID　＃をつける
     * @param gridFilterId グリッドのフィルタのID　＃をつけない
     * @param checkboxId
     * @param columnName
     * @param filterKey
     */
    CommonController.prototype.setFilterAction = function (gridId, gridFilterId, checkboxId, columnName) {
        var _this = this;
        $(checkboxId).change(function () {
            _this.filterAction(gridId, gridFilterId, checkboxId, columnName);
        });
    };
    ;
    /**
     * チェックボックスとフィルタ処理を対応させる
     * @param gridId
     * @param gridFilterId
     * @param checkboxId
     * @param columnName
     * @param filterKey
     */
    CommonController.prototype.filterAction = function (gridId, gridFilterId, checkboxId, columnName) {
        var _a;
        var checked = $(checkboxId).prop("checked");
        var value = $(checkboxId).val();
        // ■値フィルタによるフィルタリング
        var grid = wijmo.Control.getControl(gridId);
        // フィルタの取得
        var filter = c1.getExtender(grid, gridFilterId);
        // カラムフィルタの取得（5列目のフィルタ）
        var columnFilter = filter.getColumnFilter(columnName);
        if (checked) {
            // 抽出条件の指定
            if (columnFilter.valueFilter.showValues != null) {
                columnFilter.valueFilter.showValues[value] = true;
            }
            else {
                var valueFilter = (_a = {}, _a[value] = true, _a);
                columnFilter.valueFilter.showValues = valueFilter;
            }
        }
        else {
            // 抽出条件の指定
            if (columnFilter.valueFilter.showValues != null) {
                delete columnFilter.valueFilter.showValues[value];
            }
            else {
                columnFilter.valueFilter.clear();
            }
        }
        // フィルタの適用
        filter.apply();
    };
    /**
     * 検索結果のエクスポート
     */
    CommonController.prototype.exportExcel = function (filename, gridId) {
        var _this = this;
        this.loadingStart();
        var grid = wijmo.Control.getControl(gridId);
        //2020/01/06 T.Sasaki ページング対応
        var cv = grid.collectionView;
        var pageSize = cv.pageSize;
        cv.pageSize = 0;
        //非同期で実行
        setTimeout(function () {
            wijmo.grid.xlsx.FlexGridXlsxConverter.save(grid, _this.flexGridXlsxOptions, filename);
            //this.loadingEnd();
        }, this.loadingEndTransitionDuration);
        //2020/01/06 T.Sasaki ページング対応
        setTimeout(function () {
            cv.pageSize = pageSize;
            _this.loadingEnd();
        }, this.loadingEndTransitionDuration);
    };
    ;
    /**
     * Loadingの開始。loadingEndするまで画面のクリック操作ができなくなる
     */
    CommonController.prototype.loadingStart = function () {
        $("#loader").removeClass("is-hide");
        var promise = $(".loading").css({ opacity: "0" }).animate({ opacity: "100" }, this.loadingStartTransitionDuration).promise();
        if (this.loadingPromises == null)
            this.loadingPromises = [promise];
        else
            this.loadingPromises.push(promise);
    };
    /**
     * Loadingの終了。loadingEndするまで画面のクリック操作ができなくなる
     */
    CommonController.prototype.loadingEnd = function () {
        var _this = this;
        if (this.loadingPromises == null)
            $("#loader").addClass("is-hide");
        else
            $.when(this.loadingPromises).done(function () {
                $(".loading").css({ opacity: "100" }).animate({ opacity: "0" }, _this.loadingEndTransitionDuration, function () {
                    $("#loader").addClass("is-hide");
                });
            });
    };
    /**
     *  画面遷移時のLoading表示。別タブ/ウィンドウで開くクリックの場合、loadingを表示しない。
     * @description ロジックはMediaWikiから流用
     */
    CommonController.prototype.linkLoadingStart = function (event) {
        if (event == null)
            return;
        var button = event.button;
        // Add which for click: 1 === left; 2 === middle; 3 === right
        // Note: button is not normalized, so don't use it
        if (!event.which && button !== undefined) {
            event.which = (button & 1 ? 1 : (button & 2 ? 3 : (button & 4 ? 2 : 0)));
        }
        /*
         * 別タブ/ウィンドウで開くクリックの判定箇所
         * https://github.com/wikimedia/mediawiki-extensions-MultimediaViewer/blob/6b83fca574e3dcc2fa4526117f88940dcfc06f30/resources/mmv/mmv.bootstrap.js#L431-L434
         */
        if ((event.button !== 0 && event.which !== 1) || event.altKey || event.ctrlKey || event.shiftKey || event.metaKey) {
            // 別タブ/ウィンドウで開くクリック
        }
        else {
            // 通常のクリック
            this.loadingStart();
        }
    };
    /**
     * サイドパネルを初期化
     * @param width サイドパネルの幅
     */
    CommonController.prototype.initializeSidePanelToggle = function () {
        /* Set the width of the side navigation to (width) */
        $(".sidepanel-toggle").click(function (_e) {
            $('body').toggleClass('side-open');
        });
        /* Set the width of the side navigation to 0 */
        $(".sidepanel").click(function (_e) {
            $('body').toggleClass('side-open');
        });
    };
    /**
     * グリッドレイアウトの保存
     */
    CommonController.prototype.saveColumnLayout = function (keyName, columnLayout) {
        localStorage.setItem(keyName, columnLayout);
    };
    ;
    /**
     * グリッドレイアウトの読み込み
     */
    CommonController.prototype.loadColumnLayout = function (keyName) {
        var layout = localStorage.getItem(keyName);
        if (layout != null)
            return layout;
        else
            return null;
    };
    ;
    /**
     * グリッドの高さをウインドウに合わせる
     * @param gridId グリッドID
     * @param anotherElements グリッド以外の要素のID(ヘッダ、フッタは除く)
     */
    CommonController.prototype.adjustGridHeight = function (gridId) {
        var anotherElements = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            anotherElements[_i - 1] = arguments[_i];
        }
        var margin = 10;
        var windowHeight = window.innerHeight;
        var body = $(this.bodyContentSelector);
        var windowMargin = parseInt(body.css("padding-top")) + parseInt(body.css("padding-bottom"));
        var body_h = windowHeight - windowMargin;
        //パネルのサイズ調節
        var anotherHeight = _(anotherElements).map(function (x) { return $(x).outerHeight(true); }).sum();
        //パネル内の表のサイズ調節
        $(gridId)[0].style.height = body_h - anotherHeight - margin + "px";
        wijmo.Control.invalidateAll();
    };
    /**
     * 初期設定グリッドの高さをウインドウに合わせる
     * @param gridId グリッドID
     * @param anotherElements グリッド以外の要素のID(ヘッダ、フッタは除く)
     */
    CommonController.prototype.initializeAdjustGridHeight = function (gridId) {
        var _this = this;
        var anotherElements = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            anotherElements[_i - 1] = arguments[_i];
        }
        this.adjustGridHeight.apply(this, __spreadArrays([gridId], anotherElements));
        $(window).on("load resize", function () {
            _this.adjustGridHeight.apply(_this, __spreadArrays([gridId], anotherElements));
        });
    };
    /** ボタン押下時のLoading表示の初期設定 */
    CommonController.prototype.initializeSubmitLoading = function (submitButtonId) {
        var _this = this;
        if (submitButtonId === void 0) { submitButtonId = null; }
        var LinkIds = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            LinkIds[_i - 1] = arguments[_i];
        }
        if (submitButtonId != null) {
            $(submitButtonId).click(function (e) {
                //クライアント入力チェックでOKの場合のみ
                if ($("#mainForm").valid()) {
                    _this.linkLoadingStart(e);
                }
            });
        }
        _.each(LinkIds, function (x) { return $(x).click(function (e) { _this.linkLoadingStart(e); }); });
    };
    /**
     * 日付入力の範囲指定で、Fromの場合Toが最大/Toの場合Fromが最小になる設定を実施
     * @param fromDateId Fromの日付入力のId(#付き)
     * @param toDateId Toの日付入力のId(#付き)
     */
    CommonController.prototype.initializeFromToInputDate = function (fromDateId, toDateId) {
        var fromDate = wijmo.Control.getControl(fromDateId);
        var toDate = wijmo.Control.getControl(toDateId);
        fromDate.valueChanged.addHandler(function (e) {
            toDate.min = e.value != null ? e.value : new Date(1900, 0, 1);
        });
        toDate.valueChanged.addHandler(function (e) {
            fromDate.max = e.value != null ? e.value : new Date(2100, 0, 1);
        });
        fromDate.onValueChanged();
        toDate.onValueChanged();
    };
    /**
     *  戻るボタン #historyback を初期化 /
     * */
    CommonController.prototype.initializeHistoryBack = function () {
        var bs = false; //history.backを実行後にページ移動が発生したかどうか
        //unload beforeunloadは「戻る」が押されたときに走るイベント
        $(window).bind("unload beforeunload", function () {
            bs = true;
        });
        $('#historyback').on("click", function (e) {
            var href = $(e.target).attr("href");
            history.back();
            setTimeout(function () {
                if (!bs) {
                    //新しいウィンドウで開いた場合など「戻る」が使えない場合はリファラーに移動する
                    location.href = href;
                }
            }, 100);
            return false;
        });
    };
    /**
     * グリッドの高さをタブパネルに合わせる
     * @param gridId グリッドID
     * @param anotherElements グリッド以外の要素のID(ヘッダ、フッタは除く)
     */
    CommonController.prototype.adjustHeightGridInTab = function (gridId, tabPanelId) {
        var anotherElements = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            anotherElements[_i - 2] = arguments[_i];
        }
        var margin = 10;
        var body = $(this.bodyContentSelector);
        var paddingBottom = parseInt(body.css("padding-bottom")); //フッタの高さ
        var tabpanel = wijmo.Control.getControl(tabPanelId);
        var selectedTab = tabpanel.selectedTab; //選択中のタブ   
        var tabPaneHeight = selectedTab.pane.clientHeight; //タブ内容領域の高さ
        var body_h = tabPaneHeight - paddingBottom;
        //パネルのサイズ調節
        var anotherHeight = _(anotherElements).map(function (x) { return $(x).outerHeight(true); }).sum();
        //パネル内の表のサイズ調節
        $(gridId)[0].style.height = body_h - anotherHeight - margin + "px";
        wijmo.Control.invalidateAll();
    };
    /**
     * 初期設定グリッドの高さをウインドウに合わせる
     * @param gridId グリッドID
     * @param anotherElements グリッド以外の要素のID(ヘッダ、フッタは除く)
     */
    CommonController.prototype.initializeAdjustHeightGridInTab = function (gridId, tabPanelId) {
        var _this = this;
        var anotherElements = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            anotherElements[_i - 2] = arguments[_i];
        }
        this.adjustHeightGridInTab.apply(this, __spreadArrays([gridId, tabPanelId], anotherElements));
        $(window).on("load resize", function () {
            _this.adjustHeightGridInTab.apply(_this, __spreadArrays([gridId, tabPanelId], anotherElements));
        });
    };
    /**
     * タブパネルの高さをウィンドウに合わせる
     * @param gridId グリッドID
     * @param anotherElements グリッド以外の要素のID(ヘッダ、フッタは除く)
     */
    CommonController.prototype.adjustHeightTabPanel = function (tabPanelId) {
        var anotherElements = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            anotherElements[_i - 1] = arguments[_i];
        }
        var margin = 10;
        var windowHeight = window.innerHeight;
        var body = $(this.bodyContentSelector);
        var windowMargin = parseInt(body.css("padding-top")) + parseInt(body.css("padding-bottom"));
        var body_h = windowHeight - windowMargin;
        var tabpanel = wijmo.Control.getControl(tabPanelId);
        var selectedTab = tabpanel.selectedTab;
        var tabHeaderHeight = selectedTab.header.clientHeight;
        //その他コントロールのサイズ
        var anotherHeight = _(anotherElements).map(function (x) { return $(x).outerHeight(true); }).sum();
        //パネル(Pane)のサイズ調節
        selectedTab.pane.style.height = body_h - anotherHeight - tabHeaderHeight - margin + "px";
        wijmo.Control.invalidateAll();
    };
    /**
     * 初期設定タブパネルの高さをウインドウに合わせる
     * @param gridId グリッドID
     * @param anotherElements グリッド以外の要素のID(ヘッダ、フッタは除く)
     */
    CommonController.prototype.initializeAdjustHeightTabPanel = function (tabPanelId) {
        var _this = this;
        var anotherElements = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            anotherElements[_i - 1] = arguments[_i];
        }
        this.adjustHeightTabPanel.apply(this, __spreadArrays([tabPanelId], anotherElements));
        $(window).on("load resize", function () {
            _this.adjustHeightTabPanel.apply(_this, __spreadArrays([tabPanelId], anotherElements));
        });
    };
    return CommonController;
}());
//commonの初期読み込み
var common = new CommonController;
//HTML読み込み後に実行する処理
$(function () {
    common.ready();
});
